FAQ
---

What are the units of OnePower's outputs?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*All* quantities in ``onepower`` include little-*h*. So,
for example, masses are in units of Msun/h, and distances in Mpc/h. This is consistent
for every quantity in ``hmf`` and ``halomod`` on which we built the ``onepower``.
Furthermore, little-h is defined as the value of the
Hubble constant divided by 100 km/s/Mpc (i.e. it is h_100, not h_70).
